/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef jellkh
#define jellkh

#include <QStackedWidget>
#include  	"con.h"

class QLabel;
class jelzlk : public QStackedWidget
<%
	Q_OBJECT
	public:
		jelzlk(QWidget *felvnl, jelzpn *nybnvn);
		jelzpn *kidlgz;
		QLabel *jlzpnt;

	public slots:
		void kivalt(const zagv&);
%>;

#endif

